@@ -2,6 +2,4 @@
 try:  # pragma: no cover
     __import__("pkg_resources").declare_namespace(__name__)
 except ImportError:  # pragma: no cover
-    from pkgutil import extend_path
-
-    __path__ = extend_path(__path__, __name__)
+    __import__("pkgutil").extend_path(__path__, __name__)  # type: ignore
