@@ -588,6 +588,16 @@ class _Slice(CubePartition):
         """tuple of int index of each derived row-element in slice."""
         return self._assembler.derived_row_idxs
 
+    @lazyproperty
+    def diff_column_idxs(self):
+        """tuple of int index of each difference column-element in slice."""
+        return self._assembler.diff_column_idxs
+
+    @lazyproperty
+    def diff_row_idxs(self):
+        """tuple of int index of each difference row-element in slice."""
+        return self._assembler.diff_row_idxs
+
     @lazyproperty
     def is_empty(self):
         return any(s == 0 for s in self.shape)
@@ -737,6 +747,17 @@ class _Slice(CubePartition):
             for column_idx in range(len(self.column_labels))
         )
 
+    @lazyproperty
+    def payload_order(self):
+        """1D np.int64 ndarray of signed int idx respecting the payload order.
+
+        Positive integers indicate the 1-indexed position in payload of regular
+        elements, while negative integers are the subtotal insertions.
+
+        Needed for reordering color palette in exporter.
+        """
+        return self._assembler.payload_order
+
     @lazyproperty
     def population_counts(self):
         """2D np.float64 ndarray of population counts per cell.
@@ -813,6 +834,17 @@ class _Slice(CubePartition):
         """1D str ndarray of name for each row, suitable for use as row headings."""
         return self._assembler.row_labels
 
+    @lazyproperty
+    def row_order(self):
+        """1D np.int64 ndarray of signed int idx for each assembled row of stripe.
+
+        Positive integers indicate the 1-indexed position in payload of regular
+        elements, while negative integers are the subtotal insertions.
+
+        Needed for reordering color palette in exporter.
+        """
+        return self._assembler.row_order
+
     @lazyproperty
     def row_percentages(self):
         return self.row_proportions * 100
@@ -1196,13 +1228,18 @@ class _Slice(CubePartition):
 
     @lazyproperty
     def table_name(self):
-        """Provides differentiated name for each stacked table of a 3D cube."""
+        """Optional table name for this Slice
+
+        Provides differentiated name for each stacked table of a 3D cube.
+        """
         if self._cube.ndim < 3:
             return None
-
         title = self._cube.name
-        table_name = self._cube.dimensions[0].valid_elements[self._slice_idx].label
-        return f"{title}: {table_name}"
+        valid_elements = self._cube.dimensions[0].valid_elements
+        if valid_elements.element_ids:
+            table_name = valid_elements[self._slice_idx].label
+            return f"{title}: {table_name}"
+        return None
 
     @lazyproperty
     def table_percentages(self):
@@ -1267,10 +1304,10 @@ class _Slice(CubePartition):
     def table_base_range(self):
         """[min, max] np.float64 ndarray range of the table_base (table-unweighted-base)
 
-        A CAT_X_CAT has a scalar for all table-unweighted-bases, but arrays have more than
-        one table-weighted-base. This collapses all the values them to the range, and
-        it is "unpruned", meaning that it is calculated before any hiding or removing
-        of empty rows/columns.
+        A CAT_X_CAT has a scalar for all table-unweighted-bases, but arrays have more
+        than one table-weighted-base. This collapses all the values them to the range,
+        and it is "unpruned", meaning that it is calculated before any hiding or
+        removing of empty rows/columns.
         """
         return self._assembler.table_base_range
 
@@ -1447,6 +1484,11 @@ class _Strand(CubePartition):
         """tuple of int index of each derived row-element in this strand."""
         return self._assembler.derived_row_idxs
 
+    @lazyproperty
+    def diff_row_idxs(self):
+        """tuple of int index of each difference row-element in this strand."""
+        return self._assembler.diff_row_idxs
+
     @lazyproperty
     def inserted_row_idxs(self):
         """tuple of int index of each inserted row in this strand.
@@ -1495,6 +1537,17 @@ class _Strand(CubePartition):
     def name(self):
         return self.rows_dimension_name
 
+    @lazyproperty
+    def payload_order(self):
+        """1D np.int64 ndarray of signed int idx respecting the payload order.
+
+        Positive integers indicate the 1-indexed position in payload of regular
+        elements, while negative integers are the subtotal insertions.
+
+        Needed for reordering color palette in exporter.
+        """
+        return self._assembler.payload_order
+
     @lazyproperty
     def population_counts(self):
         """1D np.float64 ndarray of population count for each row of strand.
@@ -1549,6 +1602,17 @@ class _Strand(CubePartition):
         """1D str ndarray of name for each row, suitable for use as row headings."""
         return self._assembler.row_labels
 
+    @lazyproperty
+    def row_order(self):
+        """1D np.int64 ndarray of signed int idx for each assembled row of stripe.
+
+        Positive integers indicate the 1-indexed position in payload of regular
+        elements, while negative integers are the subtotal insertions.
+
+        Needed for reordering color palette in exporter.
+        """
+        return self._assembler.row_order
+
     @lazyproperty
     def rows_base(self):
         """1D np.float64 ndarray of unweighted-N for each row of slice."""
@@ -1562,6 +1626,14 @@ class _Strand(CubePartition):
         """str alias assigned to rows-dimension."""
         return self._rows_dimension.alias
 
+    @lazyproperty
+    def rows_dimension_description(self):
+        """str description assigned to rows-dimension.
+
+        Reflects the resolved dimension-description transform cascade.
+        """
+        return self._rows_dimension.description
+
     @lazyproperty
     def rows_dimension_fills(self):
         """tuple of optional RGB str like "#def032" fill color for each strand row.
@@ -1704,6 +1776,26 @@ class _Strand(CubePartition):
                 "`.sums` is undefined for a cube-result without a sum measure"
             )
 
+    @lazyproperty
+    def tab_label(self):
+        """Subvar label of strand if first dimension is a CA_SUBVAR, '""' otherwise."""
+        first_dimension = self._cube.dimensions[0]
+        return (
+            first_dimension.valid_elements[self._slice_idx].label
+            if first_dimension.dimension_type == DT.CA_SUBVAR
+            else ""
+        )
+
+    @lazyproperty
+    def tab_alias(self):
+        """Subvar alias of strand if first dimension is a CA_SUBVAR, '""' otherwise."""
+        first_dimension = self._cube.dimensions[0]
+        return (
+            first_dimension.valid_elements[self._slice_idx].alias
+            if first_dimension.dimension_type == DT.CA_SUBVAR
+            else ""
+        )
+
     @lazyproperty
     def table_base_range(self):
         """[min, max] np.float64 ndarray range of unweighted-N for this stripe.
@@ -1726,10 +1818,16 @@ class _Strand(CubePartition):
 
     @lazyproperty
     def table_name(self):
-        """Only for CA-as-0th case, provides differentiated names for stacked tables."""
+        """Optional table name for this strand
+
+        Only for CA-as-0th case, provides differentiated names for stacked tables.
+        """
         title = self._cube.name
-        table_name = self._cube.dimensions[0].valid_elements[self._slice_idx].label
-        return f"{title}: {table_name}"
+        valid_elements = self._cube.dimensions[0].valid_elements
+        if valid_elements.element_ids:
+            table_name = valid_elements[self._slice_idx].label
+            return f"{title}: {table_name}"
+        return None
 
     @lazyproperty
     def table_percentages(self):
@@ -1853,6 +1951,10 @@ class _Nub(CubePartition):
         """Int scalar of the unweighted N of the table."""
         return self._scalar.table_base
 
+    @lazyproperty
+    def table_name(self):
+        return None
+
     @lazyproperty
     def unweighted_count(self):
         """Integer scalar of total unweighted count of the table"""
