@@ -724,13 +724,13 @@ class _AllElements(_BaseElements):
         }
 
         # --- merge hide transforms with (a copy of) the existing element transforms ---
-        # TODO: Move to {**d1, **d2} syntax once we ditch Python 2
-        shimmed_transforms = {
+        hidden_transforms = {
             element_id_from_name[name]: {"hide": True}
             for name in hidden_insertion_names
+            if name in element_id_from_name
         }
-        shimmed_transforms.update(self._dimension_transforms_dict.get("elements", {}))
-        return shimmed_transforms
+        element_transforms = self._dimension_transforms_dict.get("elements", {})
+        return {**hidden_transforms, **element_transforms}
 
 
 class _ValidElements(_BaseElements):
@@ -854,8 +854,8 @@ class _ElementIdShim:
 
         0) If dimension is not a subvariables dimension, return the _id.
         1) If id matches an alias, then just use it.
-        2) If id matches a subvariable id, translate to corresponding alias.
-        3) If id matches an element id, translate to corresponding alias.
+        2) If id matches an element id, translate to corresponding alias.
+        3) If id matches a subvariable id, translate to corresponding alias.
         4) If id can be parsed to int and matches an element id, translate to alias.
         5) If id is int (or can be parsed to int) and can be used as index (eg in range
            0-# of elements), use _id'th alias.
@@ -866,10 +866,10 @@ class _ElementIdShim:
 
         if _id in self._subvar_aliases:
             return _id
-        if _id in self._subvar_ids:
-            return self._subvar_aliases[self._subvar_ids.index(_id)]
         if _id in self._raw_element_ids:
             return self._subvar_aliases[self._raw_element_ids.index(_id)]
+        if _id in self._subvar_ids:
+            return self._subvar_aliases[self._subvar_ids.index(_id)]
 
         try:
             _id = int(_id)
@@ -1203,11 +1203,11 @@ class _OrderSpec:
 
     @lazyproperty
     def marginal(self) -> MARGINAL:
-        """Member of enums.MARGINAL corresponding to "marginal": field in order transform.
+        """Member of enums.MARGINAL corresponding to marginal: field in order transform.
 
         Raises KeyError if the order dict has no "marginal": field and ValueError if the
-        value in that field is not a recognized marginal keyword. Note that not all order
-        types use the "marginal": field.
+        value in that field is not a recognized marginal keyword. Note that not all
+        order types use the "marginal": field.
         """
         return MARGINAL(self.marginal_keyname)
 
@@ -1415,11 +1415,28 @@ class _Subtotal:
             dtype=np.int64,  # force int so it can be used as index even if empty
         )
 
+    @lazyproperty
+    def fill(self) -> str:
+        """str RGB color like "#af032d" or None if not specified.
+
+        A value of None indicates the default fill should be used for this element.
+        A str value must be a hash character ("#") followed by six hexadecimal digits.
+        Three-character color contractions (like "#D07") are not valid.
+        """
+        # ---first authority is fill transform in element transforms. The base value is
+        # ---the only prior authority and that is None (use default fill color).
+        return self._subtotal_dict.get("fill", None)
+
     @lazyproperty
     def insertion_id(self) -> int:
         """int unique identifier of this subtotal within this dimension's insertions."""
         return self._subtotal_dict.get("id", self._fallback_insertion_id)
 
+    @lazyproperty
+    def is_difference(self) -> bool:
+        """True if a subtotal is a difference, False otherwise."""
+        return bool(self.subtrahend_ids)
+
     @lazyproperty
     def label(self) -> str:
         """str display name for this subtotal, suitable for use as label."""
@@ -1441,7 +1458,7 @@ class _Subtotal:
 
     @lazyproperty
     def subtrahend_idxs(self) -> np.ndarray:
-        """ndarray of int base-element offsets contributing to the negative part of subtotal.
+        """int ndarray base-element offsets contributing to the negative part of subtot.
 
         Suitable for directly indexing a numpy array object (such as base values or
         margin) to extract the addend values for this subtotal.
