@@ -245,7 +245,17 @@ class Assembler:
         categories of CAT dimensions, are not derived. Subtotals are also not derived
         in this sense, because they're not even part of the data (elements).
         """
-        return self._derived_element_idxs(self._rows_dimension, self._row_order)
+        return self._derived_element_idxs(self._rows_dimension, self.row_order)
+
+    @lazyproperty
+    def diff_row_idxs(self):
+        """tuple(int) of difference row elements' indexes, can be empty."""
+        return self._diff_element_idxs(self._rows_dimension, self.row_order)
+
+    @lazyproperty
+    def diff_column_idxs(self):
+        """tuple(int) of difference column elements' indexes, can be empty."""
+        return self._diff_element_idxs(self._columns_dimension, self._column_order)
 
     @lazyproperty
     def inserted_column_idxs(self):
@@ -257,7 +267,7 @@ class Assembler:
     def inserted_row_idxs(self):
         """tuple of int index of each subtotal row in slice."""
         # --- insertions have a negative idx in their order sequence ---
-        return tuple(i for i, row_idx in enumerate(self._row_order) if row_idx < 0)
+        return tuple(i for i, row_idx in enumerate(self.row_order) if row_idx < 0)
 
     @lazyproperty
     def means(self):
@@ -314,12 +324,12 @@ class Assembler:
         Raises `ValueError if the cube-result does not include `overlaps`
         and `valid_overlaps` cube-measures.
         """
+        base_column_idx = self._column_order[column_idx]
         if self._cube_has_overlaps:
             # If overlaps are defined, calculate significance based on them
             return self._assemble_matrix(
-                self._measures.pairwise_p_vals_for_subvar(column_idx).blocks
+                self._measures.pairwise_p_vals_for_subvar(base_column_idx).blocks
             )
-        base_column_idx = self._column_order[column_idx]
         return self._assemble_matrix(
             self._measures.pairwise_p_vals(base_column_idx).blocks
         )
@@ -337,12 +347,12 @@ class Assembler:
         Raises `ValueError if the cube-result does not include `overlaps`
         and `valid_overlaps` cube-measures.
         """
+        base_column_idx = self._column_order[column_idx]
         if self._cube_has_overlaps:
             # If overlaps are defined, calculate significance based on them
             return self._assemble_matrix(
-                self._measures.pairwise_t_stats_for_subvar(column_idx).blocks
+                self._measures.pairwise_t_stats_for_subvar(base_column_idx).blocks
             )
-        base_column_idx = self._column_order[column_idx]
         return self._assemble_matrix(
             self._measures.pairwise_t_stats(base_column_idx).blocks
         )
@@ -367,6 +377,17 @@ class Assembler:
             self._measures.pairwise_significance_means_t_stats(base_column_idx).blocks
         )
 
+    @lazyproperty
+    def payload_order(self):
+        """1D np.int64 ndarray of signed int idx for each assembled row in payload order
+
+        Negative values represent inserted subtotal-row locations.
+        """
+        empty_rows_idxs = tuple(np.where(self._measures.rows_pruning_mask)[0])
+        return np.array(
+            PayloadOrderCollator.display_order(self._rows_dimension, empty_rows_idxs)
+        )
+
     @lazyproperty
     def population_proportions(self):
         """2D np.float64 ndarray of proportions
@@ -409,7 +430,7 @@ class Assembler:
         the sequence and alias are ordered to correspond with their respective data
         row.
         """
-        return self._dimension_aliases(self._rows_dimension, self._row_order)
+        return self._dimension_aliases(self._rows_dimension, self.row_order)
 
     @lazyproperty
     def row_codes(self):
@@ -419,7 +440,7 @@ class Assembler:
         the sequence and codes are ordered to correspond with their respective data
         row.
         """
-        return self._dimension_codes(self._rows_dimension, self._row_order)
+        return self._dimension_codes(self._rows_dimension, self.row_order)
 
     @lazyproperty
     def row_labels(self):
@@ -429,7 +450,15 @@ class Assembler:
         the sequence and labels are ordered to correspond with their respective data
         row.
         """
-        return self._dimension_labels(self._rows_dimension, self._row_order)
+        return self._dimension_labels(self._rows_dimension, self.row_order)
+
+    @lazyproperty
+    def row_order(self):
+        """1D np.int64 ndarray of signed int idx for each assembled row.
+
+        Negative values represent inserted subtotal-row locations.
+        """
+        return _BaseOrderHelper.row_display_order(self._dimensions, self._measures)
 
     @lazyproperty
     def row_proportions(self):
@@ -485,8 +514,13 @@ class Assembler:
     def rows_dimension_fills(self):
         """tuple of RGB str like "#def032" fill color for each row in slice."""
         elements = self._rows_dimension.valid_elements
+        subtotals = self._rows_dimension.subtotals
         return tuple(
-            (elements[idx].fill if idx >= 0 else None) for idx in self._row_order
+            # ---Subtotals have negative sequential indexes (-1, -2, ..., -m)---
+            # ---To index them properly, we need to convert those indexes to---
+            # ---zero based positive indexes (0, 1, ... m - 1) i.e. -idx - 1---
+            (elements[idx].fill if idx >= 0 else subtotals[idx + len(subtotals)].fill)
+            for idx in self.row_order
         )
 
     @lazyproperty
@@ -500,7 +534,7 @@ class Assembler:
         return np.array(
             [
                 (elements[idx].numeric_value if idx >= 0 else np.nan)
-                for idx in self._row_order
+                for idx in self.row_order
             ]
         )
 
@@ -525,8 +559,9 @@ class Assembler:
     def rows_margin_proportion(self):
         """1D/2D np.float64 ndarray of weighted-proportion for each slice row/cell."""
         # --- an X_MR slice produces a 2D rows-margin (each cell has its own N) ---
-        # --- TODO: Should rows_margin_proportion only be defined when it's 1D? This would
-        # --- require changes to exporter to use the bases to give a "rows_margin_range"
+        # --- TODO: Should rows_margin_proportion only be defined when it's 1D? This
+        # --- would require changes to exporter to use the bases to give a
+        # --- "rows_margin_range"
         if not self._measures.rows_table_proportion.is_defined:
             return self._assemble_matrix(
                 SumSubtotals.blocks(
@@ -611,7 +646,7 @@ class Assembler:
 
             * ARR_X_ARR - 2D ndarray with a distinct table-base value per cell.
             * ARR_X - 1D ndarray of value per *row* when only rows dimension is ARR.
-            * X_ARR - 1D ndarray of value per *column* when only columns dimension is ARR
+            * X_ARR - 1D ndarray of value per *column* when only col dimension is ARR
             * CAT_X_CAT - scalar float value when slice has no MR dimension.
 
         """
@@ -736,7 +771,7 @@ class Assembler:
             return None
 
         order = (
-            self._row_order if marginal.orientation == MO.ROWS else self._column_order
+            self.row_order if marginal.orientation == MO.ROWS else self._column_order
         )
 
         return np.hstack(marginal.blocks)[order]
@@ -755,7 +790,7 @@ class Assembler:
         # --- the ordering method has been applied to determine the sequence each idx
         # --- appears in. This directly produces a final array that is exactly the
         # --- desired output.
-        return np.block(blocks)[np.ix_(self._row_order, self._column_order)]
+        return np.block(blocks)[np.ix_(self.row_order, self._column_order)]
 
     def _assemble_vector(self, base_vector, subtotals, order, diffs_nan=False):
         """Return 1D ndarray of `base_vector` with inserted `subtotals`, in `order`.
@@ -808,18 +843,22 @@ class Assembler:
         )
 
     def _derived_element_idxs(self, dimension, order):
-        """Return tuple(int) of derived elements' indices for a dimension."""
-        return tuple(
-            element_index
-            for element_index, derived in enumerate(
-                np.array(
-                    [e.derived for e in dimension.valid_elements]
-                    # ---Subtotals are not real elements and hence not derived
-                    + [False for _ in dimension.subtotals]
-                )[order]
-            )
-            if derived
-        )
+        """Return tuple(int) of derived elements' indices for a dimension.
+
+        Subtotals cannot be derived elements. Only some elements (subvariables) can.
+        """
+        n_subtotals = len(dimension.valid_elements)
+        derivs = [e.derived for e in dimension.valid_elements] + [False] * n_subtotals
+        return tuple(np.where(np.array(derivs)[order])[0])
+
+    def _diff_element_idxs(self, dimension, order):
+        """Return tuple(int) of difference elements' indices for a dimension.
+
+        Valid elements cannot be differences. Only some subtotals can.
+        """
+        n_valids = len(dimension.valid_elements)
+        diffs = [False] * n_valids + [e.is_difference for e in dimension.subtotals]
+        return tuple(np.where(np.array(diffs)[order])[0])
 
     def _dimension_aliases(self, dimension, order):
         """1D str ndarray of alias for each vector of `dimension`.
@@ -863,14 +902,6 @@ class Assembler:
         col_significance[:] = [tuple(np.where(sig_row)[0]) for sig_row in significance]
         return col_significance
 
-    @lazyproperty
-    def _row_order(self):
-        """1D np.int64 ndarray of signed int idx for each assembled row.
-
-        Negative values represent inserted subtotal-row locations.
-        """
-        return _BaseOrderHelper.row_display_order(self._dimensions, self._measures)
-
     @lazyproperty
     def _row_subtotals(self):
         """Sequence of _Subtotal object for each inserted row."""
