@@ -44,6 +44,8 @@ class StripeAssembler:
     def derived_row_idxs(self):
         """tuple of int index of each derived row-element in this stripe.
 
+        Subtotals cannot be derived
+
         An element is derived if it's a subvariable of a multiple response dimension,
         which has been produced by the zz9, and inserted into the response data.
 
@@ -51,17 +53,21 @@ class StripeAssembler:
         categories of CAT dimensions, are not derived. Subtotals are also not derived
         in this sense, because they're not even part of the data (elements).
         """
-        return tuple(
-            element_idx
-            for element_idx, derived in enumerate(
-                np.array(
-                    [e.derived for e in self._rows_dimension.valid_elements]
-                    # ---Subtotals are not data elements, and hence not derived
-                    + [False for _ in self._rows_dimension.subtotals]
-                )[self._row_order]
-            )
-            if derived
-        )
+        rows_dim = self._rows_dimension
+        n_subtotals = len(rows_dim.subtotals)
+        derivs = [e.derived for e in rows_dim.valid_elements] + [False] * n_subtotals
+        return tuple(np.where(np.array(derivs)[self.row_order])[0])
+
+    @lazyproperty
+    def diff_row_idxs(self):
+        """tuple of int index of each difference row-element in this stripe.
+
+        Valid elements are cannot be differences, only some subtotals can.
+        """
+        rows_dim = self._rows_dimension
+        n_valids = len(rows_dim.valid_elements)
+        diffs = [False] * n_valids + [e.is_difference for e in rows_dim.subtotals]
+        return tuple(np.where(np.array(diffs)[self.row_order])[0])
 
     @lazyproperty
     def inserted_row_idxs(self):
@@ -70,7 +76,7 @@ class StripeAssembler:
         Provided index values correspond rows after any insertion of subtotals,
         re-ordering, and hiding/pruning.
         """
-        return tuple(i for i, row_idx in enumerate(self._row_order) if row_idx < 0)
+        return tuple(i for i, row_idx in enumerate(self.row_order) if row_idx < 0)
 
     @lazyproperty
     def means(self):
@@ -80,6 +86,17 @@ class StripeAssembler:
         """
         return self._assemble_vector(self._measures.means.blocks)
 
+    @lazyproperty
+    def payload_order(self):
+        """1D np.int64 ndarray of signed int idx respecting the payload order"""
+        empty_row_idxs = tuple(
+            i for i, N in enumerate(self._measures.pruning_base) if N == 0
+        )
+        return np.array(
+            PayloadOrderCollator.display_order(self._rows_dimension, empty_row_idxs),
+            dtype=int,
+        )
+
     @lazyproperty
     def population_proportions(self):
         """1D np.float64 population-proportion for each row
@@ -108,7 +125,7 @@ class StripeAssembler:
 
         This count includes inserted rows but not rows that have been hidden/pruned.
         """
-        return len(self._row_order)
+        return len(self.row_order)
 
     @lazyproperty
     def row_aliases(self):
@@ -120,7 +137,7 @@ class StripeAssembler:
         """
         return np.array(
             self._rows_dimension.element_aliases + self._rows_dimension.subtotal_aliases
-        )[self._row_order]
+        )[self.row_order]
 
     @lazyproperty
     def row_codes(self):
@@ -132,7 +149,7 @@ class StripeAssembler:
         """
         return np.array(
             self._rows_dimension.element_ids + self._rows_dimension.insertion_ids
-        )[self._row_order]
+        )[self.row_order]
 
     @lazyproperty
     def row_labels(self):
@@ -144,7 +161,21 @@ class StripeAssembler:
         """
         return np.array(
             self._rows_dimension.element_labels + self._rows_dimension.subtotal_labels
-        )[self._row_order]
+        )[self.row_order]
+
+    @lazyproperty
+    def row_order(self):
+        """1D np.int64 ndarray of signed int idx for each assembled row of stripe.
+
+        Negative values represent inserted subtotal-row locations. Indices appear in the
+        order rows are to appear in the final result.
+        """
+        # --- specify dtype explicitly to prevent error when display-order is empty. The
+        # --- default dtype is float, which cannot be used to index an array.
+        return np.array(
+            _BaseOrderHelper.display_order(self._rows_dimension, self._measures),
+            dtype=int,
+        )
 
     @lazyproperty
     def rows_dimension_fills(self):
@@ -157,8 +188,17 @@ class StripeAssembler:
         color for that row should be used, probably coming from a caller-defined theme.
         """
         element_fills = tuple(e.fill for e in self._rows_dimension.valid_elements)
+        subtotal_fills = tuple(st.fill for st in self._rows_dimension.subtotals)
         return tuple(
-            (element_fills[idx] if idx > -1 else None) for idx in self._row_order
+            # ---Subtotals have negative sequential indexes (-1, -2, ..., -m)---
+            # ---To index them properly, we need to convert those indexes to---
+            # ---zero based positive indexes (0, 1, ... m - 1) i.e. -idx - 1---
+            (
+                element_fills[idx]
+                if idx > -1
+                else subtotal_fills[idx + len(subtotal_fills)]
+            )
+            for idx in self.row_order
         )
 
     @lazyproperty
@@ -273,7 +313,7 @@ class StripeAssembler:
 
     @lazyproperty
     def unweighted_bases(self):
-        """1D np.float64 ndarray of (unweighted) table-proportion denominator per row."""
+        """1D np.float64 ndarray of unweighted table-proportion denominator per row."""
         return self._assemble_vector(self._measures.unweighted_bases.blocks)
 
     @lazyproperty
@@ -298,7 +338,7 @@ class StripeAssembler:
         values of the stripe vector. The returned array is sequenced in the computed
         row order including possibly removing hidden or pruned values.
         """
-        return np.concatenate(blocks)[self._row_order]
+        return np.concatenate(blocks)[self.row_order]
 
     @lazyproperty
     def _measures(self):
@@ -307,20 +347,6 @@ class StripeAssembler:
             self._cube, self._rows_dimension, self._ca_as_0th, self._slice_idx
         )
 
-    @lazyproperty
-    def _row_order(self):
-        """1D np.int64 ndarray of signed int idx for each assembled row of stripe.
-
-        Negative values represent inserted subtotal-row locations. Indices appear in the
-        order rows are to appear in the final result.
-        """
-        # --- specify dtype explicitly to prevent error when display-order is empty. The
-        # --- default dtype is float, which cannot be used to index an array.
-        return np.array(
-            _BaseOrderHelper.display_order(self._rows_dimension, self._measures),
-            dtype=int,
-        )
-
 
 # === ORDER HELPERS ===
 
@@ -501,6 +527,7 @@ class _SortByMeasureHelper(_BaseSortByValueHelper):
             "percent_stderr": "table_proportion_stderrs",
             "population": "population_proportions",  # strictly proportional
             "population_moe": "population_proportion_stderrs",  # strictly proportional
+            "share_sum": "share_sum",
             "sum": "sums",
         }.get(measure_keyname)
 
