@@ -419,9 +419,9 @@ def test_cat_x_mr_x_mr_row_std_err():
     row_std_err = slice_.row_std_err
 
     assert row_std_err.tolist() == [
-        [0.005062449141597438, 0.006313386789860505],
-        [0.012489721142934502, 0.015435416534978305],
-        [0.012747222182198531, 0.015713252542485612],
+        pytest.approx([0.005062449141597438, 0.006313386789860505]),
+        pytest.approx([0.012489721142934502, 0.015435416534978305]),
+        pytest.approx([0.012747222182198531, 0.015713252542485612]),
     ]
 
 
