@@ -969,12 +969,12 @@ class TestOverlapsPairwiseSignificance:
         slice_ = Cube(OL.MR_X_MR_REALISTIC_EXAMPLE, transforms=transforms).partitions[0]
 
         assert slice_.pairwise_indices.tolist() == [
-            [(0, 1, 2, 3, 4), (1, 2, 3, 4), (4,), (4,), (1, 2, 4)],
-            [(1, 4), (1, 2, 3, 4), (4,), (1, 3, 4), (1, 4)],
-            [(4,), (4,), (0, 2, 3, 4), (4,), (0, 2, 4)],
-            [(4,), (1, 4), (4,), (0, 1, 3, 4), (1, 4)],
-            [(4,), (1, 4), (4,), (1, 4), (0, 1, 2, 4)],
-            [(1,), (1,), (), (1,), (1,)],
+            [(1, 2, 3, 4), (4,), (4,), (1, 2, 4), ()],
+            [(1, 2, 3, 4), (4,), (1, 3, 4), (1, 4), ()],
+            [(4,), (0, 2, 3, 4), (4,), (0, 2, 4), ()],
+            [(1, 4), (4,), (0, 1, 3, 4), (1, 4), ()],
+            [(1, 4), (4,), (1, 4), (0, 1, 2, 4), ()],
+            [(1,), (), (1,), (1,), (0, 1, 2, 3)],
         ]
 
     def test_pairwise_sig_for_mr_x_mr_vs_mr_single_subvar_x_mr(self):
