@@ -31,7 +31,6 @@ from cr.cube.matrix.measure import (
     _ColumnComparableCounts,
     _ColumnIndex,
     _ColumnProportions,
-    _ColumnProportionVariances,
     _ColumnShareSum,
     _ColumnStandardError,
     _ColumnUnweightedBases,
@@ -41,9 +40,9 @@ from cr.cube.matrix.measure import (
     _PopulationStandardError,
     _MarginTableProportion,
     _MarginTableBase,
+    _ProportionVariances,
     _Pvalues,
     _RowComparableCounts,
-    _RowProportionVariances,
     _RowProportions,
     _RowStandardError,
     _RowShareSum,
@@ -58,7 +57,6 @@ from cr.cube.matrix.measure import (
     _MarginWeightedBase,
     _Sums,
     _TotalShareSum,
-    _TableProportionVariances,
     _TableProportions,
     _TableStandardError,
     _TableUnweightedBases,
@@ -89,7 +87,7 @@ class DescribeAssembler:
             ("column_comparable_counts", _ColumnComparableCounts),
             ("column_index", _ColumnIndex),
             ("column_proportions", _ColumnProportions),
-            ("column_proportion_variances", _ColumnProportionVariances),
+            ("column_proportion_variances", _ProportionVariances),
             ("column_share_sum", _ColumnShareSum),
             ("column_std_err", _ColumnStandardError),
             ("column_unweighted_bases", _ColumnUnweightedBases),
@@ -100,7 +98,7 @@ class DescribeAssembler:
             ("pvalues", _Pvalues),
             ("row_comparable_counts", _RowComparableCounts),
             ("row_proportions", _RowProportions),
-            ("row_proportion_variances", _RowProportionVariances),
+            ("row_proportion_variances", _ProportionVariances),
             ("row_share_sum", _RowShareSum),
             ("row_std_err", _RowStandardError),
             ("row_unweighted_bases", _RowUnweightedBases),
@@ -108,7 +106,7 @@ class DescribeAssembler:
             ("stddev", _StdDev),
             ("sums", _Sums),
             ("table_proportions", _TableProportions),
-            ("table_proportion_variances", _TableProportionVariances),
+            ("table_proportion_variances", _ProportionVariances),
             ("table_std_err", _TableStandardError),
             ("table_unweighted_bases", _TableUnweightedBases),
             ("table_weighted_bases", _TableWeightedBases),
@@ -427,18 +425,37 @@ class DescribeAssembler:
 
         assert rows_base == [[1, 2, 3], [4, 5, 6], [7, 8, 9]]
 
+    @pytest.mark.parametrize(
+        "order, expected_fills",
+        (
+            ((2, -2, 0, -1), ("#f00ba5", "STF1", "#000000", "STF2")),
+            ((0, 1, 2, -2, -1), ("#000000", "#111111", "#f00ba5", "STF1", "STF2")),
+            ((-2, -1, 0, 1, 2), ("STF1", "STF2", "#000000", "#111111", "#f00ba5")),
+            ((-1, -2, 2, 1, 0), ("STF2", "STF1", "#f00ba5", "#111111", "#000000")),
+        ),
+    )
     def it_knows_the_rows_dimension_fills(
-        self, request, _rows_dimension_prop_, dimension_, _row_order_prop_
+        self,
+        request,
+        _rows_dimension_prop_,
+        dimension_,
+        _row_order_prop_,
+        order,
+        expected_fills,
     ):
+        element_fills = ("#000000", "#111111", "#f00ba5")
+        subtotal_fills = ("STF1", "STF2")
         _rows_dimension_prop_.return_value = dimension_
         dimension_.valid_elements = tuple(
-            instance_mock(request, _Element, fill=fill)
-            for fill in ("#000000", "#111111", "#f00ba5")
+            instance_mock(request, _Element, fill=fill) for fill in element_fills
         )
-        _row_order_prop_.return_value = [2, -1, 0, -2]
+        dimension_.subtotals = tuple(
+            instance_mock(request, _Subtotal, fill=fill) for fill in subtotal_fills
+        )
+        _row_order_prop_.return_value = order
         assembler = Assembler(None, None, None)
 
-        assert assembler.rows_dimension_fills == ("#f00ba5", None, "#000000", None)
+        assert assembler.rows_dimension_fills == expected_fills
 
     def it_knows_the_rows_dimension_numeric_values(
         self, request, _rows_dimension_prop_, dimension_, _row_order_prop_
@@ -891,13 +908,33 @@ class DescribeAssembler:
         )
         assembler = Assembler(None, dimensions_, None)
 
-        row_order = assembler._row_order
+        row_order = assembler.row_order
 
         _BaseOrderHelper_.row_display_order.assert_called_once_with(
             dimensions_, second_order_measures_
         )
         assert row_order.tolist() == [-1, 1, -2, 2, -3, 3]
 
+    def it_knows_the_payload_order_to_help(
+        self,
+        request,
+        dimensions_,
+        _measures_prop_,
+        second_order_measures_,
+    ):
+        _measures_prop_.return_value = second_order_measures_
+        _OrderHelper_ = class_mock(
+            request, "cr.cube.matrix.assembler.PayloadOrderCollator"
+        )
+        _OrderHelper_.display_order.return_value = np.array([1, 2, 3])
+        assembler = Assembler(None, dimensions_, None)
+
+        row_order = assembler.row_order
+
+        _OrderHelper_.display_order.assert_called_once_with(dimensions_[0], ())
+
+        assert row_order.tolist() == [1, 2, 3]
+
     def it_provides_access_to_the_row_subtotals_to_help(
         self, _rows_dimension_prop_, dimension_, subtotals_
     ):
@@ -974,7 +1011,7 @@ class DescribeAssembler:
 
     @pytest.fixture
     def _row_order_prop_(self, request):
-        return property_mock(request, Assembler, "_row_order")
+        return property_mock(request, Assembler, "row_order")
 
     @pytest.fixture
     def _rows_dimension_prop_(self, request):
@@ -1526,7 +1563,7 @@ class Describe_SortRowsByDerivedColumnHelper:
 
 
 class Describe_SortRowsByInsertedColumnHelper:
-    """Unit test suite for `cr.cube.matrix.assembler._SortRowsByInsertedColumnHelper`."""
+    """Unit test suite for `cr.cube.matrix.assembler._SortRowsByInsertedColumnHelper`"""
 
     def it_extracts_the_element_values_to_help(
         self, _measure_prop_, measure_, _insertion_idx_prop_
